@@ -94,6 +94,14 @@ pub mod inline_object_5;
 pub use self::inline_object_5::InlineObject5;
 pub mod inline_object_50;
 pub use self::inline_object_50::InlineObject50;
+pub mod inline_object_51;
+pub use self::inline_object_51::InlineObject51;
+pub mod inline_object_52;
+pub use self::inline_object_52::InlineObject52;
+pub mod inline_object_53;
+pub use self::inline_object_53::InlineObject53;
+pub mod inline_object_54;
+pub use self::inline_object_54::InlineObject54;
 pub mod inline_object_6;
 pub use self::inline_object_6::InlineObject6;
 pub mod inline_object_7;
@@ -102,8 +110,6 @@ pub mod inline_object_8;
 pub use self::inline_object_8::InlineObject8;
 pub mod inline_object_9;
 pub use self::inline_object_9::InlineObject9;
-pub mod _instance_v1_zones__zone__volumes__id__server;
-pub use self::_instance_v1_zones__zone__volumes__id__server::InstanceV1ZonesZoneVolumesIdServer;
 pub mod _k8s_v1_regions__region__clusters_auto_upgrade;
 pub use self::_k8s_v1_regions__region__clusters_auto_upgrade::K8sV1RegionsRegionClustersAutoUpgrade;
 pub mod _k8s_v1_regions__region__clusters_auto_upgrade_maintenance_window;
@@ -124,24 +130,50 @@ pub mod _k8s_v1_regions__region__clusters_open_id_connect_config;
 pub use self::_k8s_v1_regions__region__clusters_open_id_connect_config::K8sV1RegionsRegionClustersOpenIdConnectConfig;
 pub mod _k8s_v1_regions__region__pools__pool_id__kubelet_args;
 pub use self::_k8s_v1_regions__region__pools__pool_id__kubelet_args::K8sV1RegionsRegionPoolsPoolIdKubeletArgs;
-pub mod scaleway_apple_silicon_v1alpha1_list_os_response;
-pub use self::scaleway_apple_silicon_v1alpha1_list_os_response::ScalewayAppleSiliconV1alpha1ListOsResponse;
-pub mod scaleway_apple_silicon_v1alpha1_list_server_types_response;
-pub use self::scaleway_apple_silicon_v1alpha1_list_server_types_response::ScalewayAppleSiliconV1alpha1ListServerTypesResponse;
-pub mod scaleway_apple_silicon_v1alpha1_list_servers_response;
-pub use self::scaleway_apple_silicon_v1alpha1_list_servers_response::ScalewayAppleSiliconV1alpha1ListServersResponse;
-pub mod scaleway_apple_silicon_v1alpha1_os;
-pub use self::scaleway_apple_silicon_v1alpha1_os::ScalewayAppleSiliconV1alpha1Os;
-pub mod scaleway_apple_silicon_v1alpha1_server;
-pub use self::scaleway_apple_silicon_v1alpha1_server::ScalewayAppleSiliconV1alpha1Server;
-pub mod scaleway_apple_silicon_v1alpha1_server_type;
-pub use self::scaleway_apple_silicon_v1alpha1_server_type::ScalewayAppleSiliconV1alpha1ServerType;
-pub mod scaleway_apple_silicon_v1alpha1_server_type_cpu;
-pub use self::scaleway_apple_silicon_v1alpha1_server_type_cpu::ScalewayAppleSiliconV1alpha1ServerTypeCpu;
-pub mod scaleway_apple_silicon_v1alpha1_server_type_disk;
-pub use self::scaleway_apple_silicon_v1alpha1_server_type_disk::ScalewayAppleSiliconV1alpha1ServerTypeDisk;
-pub mod scaleway_apple_silicon_v1alpha1_server_type_memory;
-pub use self::scaleway_apple_silicon_v1alpha1_server_type_memory::ScalewayAppleSiliconV1alpha1ServerTypeMemory;
+pub mod scaleway_baremetal_v1_bmc_access;
+pub use self::scaleway_baremetal_v1_bmc_access::ScalewayBaremetalV1BmcAccess;
+pub mod scaleway_baremetal_v1_cpu;
+pub use self::scaleway_baremetal_v1_cpu::ScalewayBaremetalV1Cpu;
+pub mod scaleway_baremetal_v1_create_server_request_install;
+pub use self::scaleway_baremetal_v1_create_server_request_install::ScalewayBaremetalV1CreateServerRequestInstall;
+pub mod scaleway_baremetal_v1_disk;
+pub use self::scaleway_baremetal_v1_disk::ScalewayBaremetalV1Disk;
+pub mod scaleway_baremetal_v1_get_server_metrics_response;
+pub use self::scaleway_baremetal_v1_get_server_metrics_response::ScalewayBaremetalV1GetServerMetricsResponse;
+pub mod scaleway_baremetal_v1_get_server_metrics_response_pings;
+pub use self::scaleway_baremetal_v1_get_server_metrics_response_pings::ScalewayBaremetalV1GetServerMetricsResponsePings;
+pub mod scaleway_baremetal_v1_ip;
+pub use self::scaleway_baremetal_v1_ip::ScalewayBaremetalV1Ip;
+pub mod scaleway_baremetal_v1_list_offers_response;
+pub use self::scaleway_baremetal_v1_list_offers_response::ScalewayBaremetalV1ListOffersResponse;
+pub mod scaleway_baremetal_v1_list_os_response;
+pub use self::scaleway_baremetal_v1_list_os_response::ScalewayBaremetalV1ListOsResponse;
+pub mod scaleway_baremetal_v1_list_server_events_response;
+pub use self::scaleway_baremetal_v1_list_server_events_response::ScalewayBaremetalV1ListServerEventsResponse;
+pub mod scaleway_baremetal_v1_list_servers_response;
+pub use self::scaleway_baremetal_v1_list_servers_response::ScalewayBaremetalV1ListServersResponse;
+pub mod scaleway_baremetal_v1_memory;
+pub use self::scaleway_baremetal_v1_memory::ScalewayBaremetalV1Memory;
+pub mod scaleway_baremetal_v1_offer;
+pub use self::scaleway_baremetal_v1_offer::ScalewayBaremetalV1Offer;
+pub mod scaleway_baremetal_v1_offer_price_per_hour;
+pub use self::scaleway_baremetal_v1_offer_price_per_hour::ScalewayBaremetalV1OfferPricePerHour;
+pub mod scaleway_baremetal_v1_offer_price_per_month;
+pub use self::scaleway_baremetal_v1_offer_price_per_month::ScalewayBaremetalV1OfferPricePerMonth;
+pub mod scaleway_baremetal_v1_os;
+pub use self::scaleway_baremetal_v1_os::ScalewayBaremetalV1Os;
+pub mod scaleway_baremetal_v1_persistent_memory;
+pub use self::scaleway_baremetal_v1_persistent_memory::ScalewayBaremetalV1PersistentMemory;
+pub mod scaleway_baremetal_v1_raid_controller;
+pub use self::scaleway_baremetal_v1_raid_controller::ScalewayBaremetalV1RaidController;
+pub mod scaleway_baremetal_v1_server;
+pub use self::scaleway_baremetal_v1_server::ScalewayBaremetalV1Server;
+pub mod scaleway_baremetal_v1_server_event;
+pub use self::scaleway_baremetal_v1_server_event::ScalewayBaremetalV1ServerEvent;
+pub mod scaleway_baremetal_v1_server_install;
+pub use self::scaleway_baremetal_v1_server_install::ScalewayBaremetalV1ServerInstall;
+pub mod scaleway_baremetal_v1_server_install_status;
+pub use self::scaleway_baremetal_v1_server_install_status::ScalewayBaremetalV1ServerInstallStatus;
 pub mod scaleway_domain_v2beta1_dns_zone;
 pub use self::scaleway_domain_v2beta1_dns_zone::ScalewayDomainV2beta1DnsZone;
 pub mod scaleway_domain_v2beta1_dns_zone_status;
@@ -228,198 +260,6 @@ pub mod scaleway_flexible_ip_v1alpha1_mac_address_status;
 pub use self::scaleway_flexible_ip_v1alpha1_mac_address_status::ScalewayFlexibleIpV1alpha1MacAddressStatus;
 pub mod scaleway_flexible_ip_v1alpha1_mac_address_type;
 pub use self::scaleway_flexible_ip_v1alpha1_mac_address_type::ScalewayFlexibleIpV1alpha1MacAddressType;
-pub mod scaleway_instance_v1_arch;
-pub use self::scaleway_instance_v1_arch::ScalewayInstanceV1Arch;
-pub mod scaleway_instance_v1_boot_type;
-pub use self::scaleway_instance_v1_boot_type::ScalewayInstanceV1BootType;
-pub mod scaleway_instance_v1_bootscript;
-pub use self::scaleway_instance_v1_bootscript::ScalewayInstanceV1Bootscript;
-pub mod scaleway_instance_v1_create_image_response;
-pub use self::scaleway_instance_v1_create_image_response::ScalewayInstanceV1CreateImageResponse;
-pub mod scaleway_instance_v1_create_ip_response;
-pub use self::scaleway_instance_v1_create_ip_response::ScalewayInstanceV1CreateIpResponse;
-pub mod scaleway_instance_v1_create_placement_group_response;
-pub use self::scaleway_instance_v1_create_placement_group_response::ScalewayInstanceV1CreatePlacementGroupResponse;
-pub mod scaleway_instance_v1_create_private_nic_response;
-pub use self::scaleway_instance_v1_create_private_nic_response::ScalewayInstanceV1CreatePrivateNicResponse;
-pub mod scaleway_instance_v1_create_security_group_response;
-pub use self::scaleway_instance_v1_create_security_group_response::ScalewayInstanceV1CreateSecurityGroupResponse;
-pub mod scaleway_instance_v1_create_security_group_rule_response;
-pub use self::scaleway_instance_v1_create_security_group_rule_response::ScalewayInstanceV1CreateSecurityGroupRuleResponse;
-pub mod scaleway_instance_v1_create_server_response;
-pub use self::scaleway_instance_v1_create_server_response::ScalewayInstanceV1CreateServerResponse;
-pub mod scaleway_instance_v1_create_snapshot_response;
-pub use self::scaleway_instance_v1_create_snapshot_response::ScalewayInstanceV1CreateSnapshotResponse;
-pub mod scaleway_instance_v1_create_volume_response;
-pub use self::scaleway_instance_v1_create_volume_response::ScalewayInstanceV1CreateVolumeResponse;
-pub mod scaleway_instance_v1_dashboard;
-pub use self::scaleway_instance_v1_dashboard::ScalewayInstanceV1Dashboard;
-pub mod scaleway_instance_v1_get_bootscript_response;
-pub use self::scaleway_instance_v1_get_bootscript_response::ScalewayInstanceV1GetBootscriptResponse;
-pub mod scaleway_instance_v1_get_dashboard_response;
-pub use self::scaleway_instance_v1_get_dashboard_response::ScalewayInstanceV1GetDashboardResponse;
-pub mod scaleway_instance_v1_get_image_response;
-pub use self::scaleway_instance_v1_get_image_response::ScalewayInstanceV1GetImageResponse;
-pub mod scaleway_instance_v1_get_ip_response;
-pub use self::scaleway_instance_v1_get_ip_response::ScalewayInstanceV1GetIpResponse;
-pub mod scaleway_instance_v1_get_placement_group_response;
-pub use self::scaleway_instance_v1_get_placement_group_response::ScalewayInstanceV1GetPlacementGroupResponse;
-pub mod scaleway_instance_v1_get_placement_group_servers_response;
-pub use self::scaleway_instance_v1_get_placement_group_servers_response::ScalewayInstanceV1GetPlacementGroupServersResponse;
-pub mod scaleway_instance_v1_get_private_nic_response;
-pub use self::scaleway_instance_v1_get_private_nic_response::ScalewayInstanceV1GetPrivateNicResponse;
-pub mod scaleway_instance_v1_get_security_group_response;
-pub use self::scaleway_instance_v1_get_security_group_response::ScalewayInstanceV1GetSecurityGroupResponse;
-pub mod scaleway_instance_v1_get_security_group_rule_response;
-pub use self::scaleway_instance_v1_get_security_group_rule_response::ScalewayInstanceV1GetSecurityGroupRuleResponse;
-pub mod scaleway_instance_v1_get_server_response;
-pub use self::scaleway_instance_v1_get_server_response::ScalewayInstanceV1GetServerResponse;
-pub mod scaleway_instance_v1_get_server_types_availability_response;
-pub use self::scaleway_instance_v1_get_server_types_availability_response::ScalewayInstanceV1GetServerTypesAvailabilityResponse;
-pub mod scaleway_instance_v1_get_server_types_availability_response_availability;
-pub use self::scaleway_instance_v1_get_server_types_availability_response_availability::ScalewayInstanceV1GetServerTypesAvailabilityResponseAvailability;
-pub mod scaleway_instance_v1_get_snapshot_response;
-pub use self::scaleway_instance_v1_get_snapshot_response::ScalewayInstanceV1GetSnapshotResponse;
-pub mod scaleway_instance_v1_get_volume_response;
-pub use self::scaleway_instance_v1_get_volume_response::ScalewayInstanceV1GetVolumeResponse;
-pub mod scaleway_instance_v1_image;
-pub use self::scaleway_instance_v1_image::ScalewayInstanceV1Image;
-pub mod scaleway_instance_v1_image_state;
-pub use self::scaleway_instance_v1_image_state::ScalewayInstanceV1ImageState;
-pub mod scaleway_instance_v1_ip;
-pub use self::scaleway_instance_v1_ip::ScalewayInstanceV1Ip;
-pub mod scaleway_instance_v1_list_bootscripts_response;
-pub use self::scaleway_instance_v1_list_bootscripts_response::ScalewayInstanceV1ListBootscriptsResponse;
-pub mod scaleway_instance_v1_list_images_response;
-pub use self::scaleway_instance_v1_list_images_response::ScalewayInstanceV1ListImagesResponse;
-pub mod scaleway_instance_v1_list_ips_response;
-pub use self::scaleway_instance_v1_list_ips_response::ScalewayInstanceV1ListIpsResponse;
-pub mod scaleway_instance_v1_list_placement_groups_response;
-pub use self::scaleway_instance_v1_list_placement_groups_response::ScalewayInstanceV1ListPlacementGroupsResponse;
-pub mod scaleway_instance_v1_list_private_nics_response;
-pub use self::scaleway_instance_v1_list_private_nics_response::ScalewayInstanceV1ListPrivateNicsResponse;
-pub mod scaleway_instance_v1_list_security_group_rules_response;
-pub use self::scaleway_instance_v1_list_security_group_rules_response::ScalewayInstanceV1ListSecurityGroupRulesResponse;
-pub mod scaleway_instance_v1_list_security_groups_response;
-pub use self::scaleway_instance_v1_list_security_groups_response::ScalewayInstanceV1ListSecurityGroupsResponse;
-pub mod scaleway_instance_v1_list_server_actions_response;
-pub use self::scaleway_instance_v1_list_server_actions_response::ScalewayInstanceV1ListServerActionsResponse;
-pub mod scaleway_instance_v1_list_server_user_data_response;
-pub use self::scaleway_instance_v1_list_server_user_data_response::ScalewayInstanceV1ListServerUserDataResponse;
-pub mod scaleway_instance_v1_list_servers_response;
-pub use self::scaleway_instance_v1_list_servers_response::ScalewayInstanceV1ListServersResponse;
-pub mod scaleway_instance_v1_list_servers_types_response;
-pub use self::scaleway_instance_v1_list_servers_types_response::ScalewayInstanceV1ListServersTypesResponse;
-pub mod scaleway_instance_v1_list_snapshots_response;
-pub use self::scaleway_instance_v1_list_snapshots_response::ScalewayInstanceV1ListSnapshotsResponse;
-pub mod scaleway_instance_v1_list_volumes_response;
-pub use self::scaleway_instance_v1_list_volumes_response::ScalewayInstanceV1ListVolumesResponse;
-pub mod scaleway_instance_v1_list_volumes_types_response;
-pub use self::scaleway_instance_v1_list_volumes_types_response::ScalewayInstanceV1ListVolumesTypesResponse;
-pub mod scaleway_instance_v1_placement_group;
-pub use self::scaleway_instance_v1_placement_group::ScalewayInstanceV1PlacementGroup;
-pub mod scaleway_instance_v1_placement_group_policy_mode;
-pub use self::scaleway_instance_v1_placement_group_policy_mode::ScalewayInstanceV1PlacementGroupPolicyMode;
-pub mod scaleway_instance_v1_placement_group_policy_type;
-pub use self::scaleway_instance_v1_placement_group_policy_type::ScalewayInstanceV1PlacementGroupPolicyType;
-pub mod scaleway_instance_v1_placement_group_server;
-pub use self::scaleway_instance_v1_placement_group_server::ScalewayInstanceV1PlacementGroupServer;
-pub mod scaleway_instance_v1_private_nic;
-pub use self::scaleway_instance_v1_private_nic::ScalewayInstanceV1PrivateNic;
-pub mod scaleway_instance_v1_security_group;
-pub use self::scaleway_instance_v1_security_group::ScalewayInstanceV1SecurityGroup;
-pub mod scaleway_instance_v1_security_group_rule;
-pub use self::scaleway_instance_v1_security_group_rule::ScalewayInstanceV1SecurityGroupRule;
-pub mod scaleway_instance_v1_security_group_rule_action;
-pub use self::scaleway_instance_v1_security_group_rule_action::ScalewayInstanceV1SecurityGroupRuleAction;
-pub mod scaleway_instance_v1_security_group_rule_direction;
-pub use self::scaleway_instance_v1_security_group_rule_direction::ScalewayInstanceV1SecurityGroupRuleDirection;
-pub mod scaleway_instance_v1_security_group_rule_protocol;
-pub use self::scaleway_instance_v1_security_group_rule_protocol::ScalewayInstanceV1SecurityGroupRuleProtocol;
-pub mod scaleway_instance_v1_security_group_template;
-pub use self::scaleway_instance_v1_security_group_template::ScalewayInstanceV1SecurityGroupTemplate;
-pub mod scaleway_instance_v1_server;
-pub use self::scaleway_instance_v1_server::ScalewayInstanceV1Server;
-pub mod scaleway_instance_v1_server_action;
-pub use self::scaleway_instance_v1_server_action::ScalewayInstanceV1ServerAction;
-pub mod scaleway_instance_v1_server_action_response;
-pub use self::scaleway_instance_v1_server_action_response::ScalewayInstanceV1ServerActionResponse;
-pub mod scaleway_instance_v1_server_bootscript;
-pub use self::scaleway_instance_v1_server_bootscript::ScalewayInstanceV1ServerBootscript;
-pub mod scaleway_instance_v1_server_image;
-pub use self::scaleway_instance_v1_server_image::ScalewayInstanceV1ServerImage;
-pub mod scaleway_instance_v1_server_ipv6;
-pub use self::scaleway_instance_v1_server_ipv6::ScalewayInstanceV1ServerIpv6;
-pub mod scaleway_instance_v1_server_location;
-pub use self::scaleway_instance_v1_server_location::ScalewayInstanceV1ServerLocation;
-pub mod scaleway_instance_v1_server_placement_group;
-pub use self::scaleway_instance_v1_server_placement_group::ScalewayInstanceV1ServerPlacementGroup;
-pub mod scaleway_instance_v1_server_public_ip;
-pub use self::scaleway_instance_v1_server_public_ip::ScalewayInstanceV1ServerPublicIp;
-pub mod scaleway_instance_v1_server_security_group;
-pub use self::scaleway_instance_v1_server_security_group::ScalewayInstanceV1ServerSecurityGroup;
-pub mod scaleway_instance_v1_server_summary;
-pub use self::scaleway_instance_v1_server_summary::ScalewayInstanceV1ServerSummary;
-pub mod scaleway_instance_v1_server_type;
-pub use self::scaleway_instance_v1_server_type::ScalewayInstanceV1ServerType;
-pub mod scaleway_instance_v1_server_type_network;
-pub use self::scaleway_instance_v1_server_type_network::ScalewayInstanceV1ServerTypeNetwork;
-pub mod scaleway_instance_v1_server_type_network_interface;
-pub use self::scaleway_instance_v1_server_type_network_interface::ScalewayInstanceV1ServerTypeNetworkInterface;
-pub mod scaleway_instance_v1_server_type_per_volume_constraint;
-pub use self::scaleway_instance_v1_server_type_per_volume_constraint::ScalewayInstanceV1ServerTypePerVolumeConstraint;
-pub mod scaleway_instance_v1_server_type_per_volume_constraint_l_ssd;
-pub use self::scaleway_instance_v1_server_type_per_volume_constraint_l_ssd::ScalewayInstanceV1ServerTypePerVolumeConstraintLSsd;
-pub mod scaleway_instance_v1_server_type_volumes_constraint;
-pub use self::scaleway_instance_v1_server_type_volumes_constraint::ScalewayInstanceV1ServerTypeVolumesConstraint;
-pub mod scaleway_instance_v1_server_types_availability;
-pub use self::scaleway_instance_v1_server_types_availability::ScalewayInstanceV1ServerTypesAvailability;
-pub mod scaleway_instance_v1_set_image_response;
-pub use self::scaleway_instance_v1_set_image_response::ScalewayInstanceV1SetImageResponse;
-pub mod scaleway_instance_v1_set_placement_group_response;
-pub use self::scaleway_instance_v1_set_placement_group_response::ScalewayInstanceV1SetPlacementGroupResponse;
-pub mod scaleway_instance_v1_set_placement_group_servers_response;
-pub use self::scaleway_instance_v1_set_placement_group_servers_response::ScalewayInstanceV1SetPlacementGroupServersResponse;
-pub mod scaleway_instance_v1_set_security_group_response;
-pub use self::scaleway_instance_v1_set_security_group_response::ScalewayInstanceV1SetSecurityGroupResponse;
-pub mod scaleway_instance_v1_set_security_group_rule_response;
-pub use self::scaleway_instance_v1_set_security_group_rule_response::ScalewayInstanceV1SetSecurityGroupRuleResponse;
-pub mod scaleway_instance_v1_set_snapshot_response;
-pub use self::scaleway_instance_v1_set_snapshot_response::ScalewayInstanceV1SetSnapshotResponse;
-pub mod scaleway_instance_v1_set_volume_response;
-pub use self::scaleway_instance_v1_set_volume_response::ScalewayInstanceV1SetVolumeResponse;
-pub mod scaleway_instance_v1_snapshot;
-pub use self::scaleway_instance_v1_snapshot::ScalewayInstanceV1Snapshot;
-pub mod scaleway_instance_v1_snapshot_base_volume;
-pub use self::scaleway_instance_v1_snapshot_base_volume::ScalewayInstanceV1SnapshotBaseVolume;
-pub mod scaleway_instance_v1_snapshot_state;
-pub use self::scaleway_instance_v1_snapshot_state::ScalewayInstanceV1SnapshotState;
-pub mod scaleway_instance_v1_task;
-pub use self::scaleway_instance_v1_task::ScalewayInstanceV1Task;
-pub mod scaleway_instance_v1_update_ip_response;
-pub use self::scaleway_instance_v1_update_ip_response::ScalewayInstanceV1UpdateIpResponse;
-pub mod scaleway_instance_v1_update_placement_group_response;
-pub use self::scaleway_instance_v1_update_placement_group_response::ScalewayInstanceV1UpdatePlacementGroupResponse;
-pub mod scaleway_instance_v1_update_placement_group_servers_response;
-pub use self::scaleway_instance_v1_update_placement_group_servers_response::ScalewayInstanceV1UpdatePlacementGroupServersResponse;
-pub mod scaleway_instance_v1_update_server_response;
-pub use self::scaleway_instance_v1_update_server_response::ScalewayInstanceV1UpdateServerResponse;
-pub mod scaleway_instance_v1_update_volume_response;
-pub use self::scaleway_instance_v1_update_volume_response::ScalewayInstanceV1UpdateVolumeResponse;
-pub mod scaleway_instance_v1_volume;
-pub use self::scaleway_instance_v1_volume::ScalewayInstanceV1Volume;
-pub mod scaleway_instance_v1_volume_summary;
-pub use self::scaleway_instance_v1_volume_summary::ScalewayInstanceV1VolumeSummary;
-pub mod scaleway_instance_v1_volume_template;
-pub use self::scaleway_instance_v1_volume_template::ScalewayInstanceV1VolumeTemplate;
-pub mod scaleway_instance_v1_volume_type;
-pub use self::scaleway_instance_v1_volume_type::ScalewayInstanceV1VolumeType;
-pub mod scaleway_instance_v1_volume_type_capabilities;
-pub use self::scaleway_instance_v1_volume_type_capabilities::ScalewayInstanceV1VolumeTypeCapabilities;
-pub mod scaleway_instance_v1_volume_type_constraints;
-pub use self::scaleway_instance_v1_volume_type_constraints::ScalewayInstanceV1VolumeTypeConstraints;
-pub mod scaleway_instance_v1_volume_volume_type;
-pub use self::scaleway_instance_v1_volume_volume_type::ScalewayInstanceV1VolumeVolumeType;
 pub mod scaleway_k8s_v1_cluster;
 pub use self::scaleway_k8s_v1_cluster::ScalewayK8sV1Cluster;
 pub mod scaleway_k8s_v1_cluster_auto_upgrade;
@@ -456,6 +296,94 @@ pub mod scaleway_k8s_v1_runtime;
 pub use self::scaleway_k8s_v1_runtime::ScalewayK8sV1Runtime;
 pub mod scaleway_k8s_v1_version;
 pub use self::scaleway_k8s_v1_version::ScalewayK8sV1Version;
+pub mod scaleway_rdb_v1_acl_rule;
+pub use self::scaleway_rdb_v1_acl_rule::ScalewayRdbV1AclRule;
+pub mod scaleway_rdb_v1_acl_rule_action;
+pub use self::scaleway_rdb_v1_acl_rule_action::ScalewayRdbV1AclRuleAction;
+pub mod scaleway_rdb_v1_acl_rule_direction;
+pub use self::scaleway_rdb_v1_acl_rule_direction::ScalewayRdbV1AclRuleDirection;
+pub mod scaleway_rdb_v1_acl_rule_protocol;
+pub use self::scaleway_rdb_v1_acl_rule_protocol::ScalewayRdbV1AclRuleProtocol;
+pub mod scaleway_rdb_v1_acl_rule_request;
+pub use self::scaleway_rdb_v1_acl_rule_request::ScalewayRdbV1AclRuleRequest;
+pub mod scaleway_rdb_v1_add_instance_acl_rules_response;
+pub use self::scaleway_rdb_v1_add_instance_acl_rules_response::ScalewayRdbV1AddInstanceAclRulesResponse;
+pub mod scaleway_rdb_v1_add_instance_settings_response;
+pub use self::scaleway_rdb_v1_add_instance_settings_response::ScalewayRdbV1AddInstanceSettingsResponse;
+pub mod scaleway_rdb_v1_database;
+pub use self::scaleway_rdb_v1_database::ScalewayRdbV1Database;
+pub mod scaleway_rdb_v1_database_backup;
+pub use self::scaleway_rdb_v1_database_backup::ScalewayRdbV1DatabaseBackup;
+pub mod scaleway_rdb_v1_database_engine;
+pub use self::scaleway_rdb_v1_database_engine::ScalewayRdbV1DatabaseEngine;
+pub mod scaleway_rdb_v1_delete_instance_acl_rules_response;
+pub use self::scaleway_rdb_v1_delete_instance_acl_rules_response::ScalewayRdbV1DeleteInstanceAclRulesResponse;
+pub mod scaleway_rdb_v1_delete_instance_settings_response;
+pub use self::scaleway_rdb_v1_delete_instance_settings_response::ScalewayRdbV1DeleteInstanceSettingsResponse;
+pub mod scaleway_rdb_v1_endpoint;
+pub use self::scaleway_rdb_v1_endpoint::ScalewayRdbV1Endpoint;
+pub mod scaleway_rdb_v1_engine_setting;
+pub use self::scaleway_rdb_v1_engine_setting::ScalewayRdbV1EngineSetting;
+pub mod scaleway_rdb_v1_engine_setting_float_max;
+pub use self::scaleway_rdb_v1_engine_setting_float_max::ScalewayRdbV1EngineSettingFloatMax;
+pub mod scaleway_rdb_v1_engine_setting_float_min;
+pub use self::scaleway_rdb_v1_engine_setting_float_min::ScalewayRdbV1EngineSettingFloatMin;
+pub mod scaleway_rdb_v1_engine_version;
+pub use self::scaleway_rdb_v1_engine_version::ScalewayRdbV1EngineVersion;
+pub mod scaleway_rdb_v1_instance;
+pub use self::scaleway_rdb_v1_instance::ScalewayRdbV1Instance;
+pub mod scaleway_rdb_v1_instance_backup_schedule;
+pub use self::scaleway_rdb_v1_instance_backup_schedule::ScalewayRdbV1InstanceBackupSchedule;
+pub mod scaleway_rdb_v1_instance_endpoint;
+pub use self::scaleway_rdb_v1_instance_endpoint::ScalewayRdbV1InstanceEndpoint;
+pub mod scaleway_rdb_v1_instance_log;
+pub use self::scaleway_rdb_v1_instance_log::ScalewayRdbV1InstanceLog;
+pub mod scaleway_rdb_v1_instance_metrics;
+pub use self::scaleway_rdb_v1_instance_metrics::ScalewayRdbV1InstanceMetrics;
+pub mod scaleway_rdb_v1_instance_setting;
+pub use self::scaleway_rdb_v1_instance_setting::ScalewayRdbV1InstanceSetting;
+pub mod scaleway_rdb_v1_instance_volume;
+pub use self::scaleway_rdb_v1_instance_volume::ScalewayRdbV1InstanceVolume;
+pub mod scaleway_rdb_v1_list_database_backups_response;
+pub use self::scaleway_rdb_v1_list_database_backups_response::ScalewayRdbV1ListDatabaseBackupsResponse;
+pub mod scaleway_rdb_v1_list_database_engines_response;
+pub use self::scaleway_rdb_v1_list_database_engines_response::ScalewayRdbV1ListDatabaseEnginesResponse;
+pub mod scaleway_rdb_v1_list_databases_response;
+pub use self::scaleway_rdb_v1_list_databases_response::ScalewayRdbV1ListDatabasesResponse;
+pub mod scaleway_rdb_v1_list_instance_acl_rules_response;
+pub use self::scaleway_rdb_v1_list_instance_acl_rules_response::ScalewayRdbV1ListInstanceAclRulesResponse;
+pub mod scaleway_rdb_v1_list_instance_logs_response;
+pub use self::scaleway_rdb_v1_list_instance_logs_response::ScalewayRdbV1ListInstanceLogsResponse;
+pub mod scaleway_rdb_v1_list_instances_response;
+pub use self::scaleway_rdb_v1_list_instances_response::ScalewayRdbV1ListInstancesResponse;
+pub mod scaleway_rdb_v1_list_node_types_response;
+pub use self::scaleway_rdb_v1_list_node_types_response::ScalewayRdbV1ListNodeTypesResponse;
+pub mod scaleway_rdb_v1_list_privileges_response;
+pub use self::scaleway_rdb_v1_list_privileges_response::ScalewayRdbV1ListPrivilegesResponse;
+pub mod scaleway_rdb_v1_list_snapshots_response;
+pub use self::scaleway_rdb_v1_list_snapshots_response::ScalewayRdbV1ListSnapshotsResponse;
+pub mod scaleway_rdb_v1_list_users_response;
+pub use self::scaleway_rdb_v1_list_users_response::ScalewayRdbV1ListUsersResponse;
+pub mod scaleway_rdb_v1_node_type;
+pub use self::scaleway_rdb_v1_node_type::ScalewayRdbV1NodeType;
+pub mod scaleway_rdb_v1_node_type_volume_constraint;
+pub use self::scaleway_rdb_v1_node_type_volume_constraint::ScalewayRdbV1NodeTypeVolumeConstraint;
+pub mod scaleway_rdb_v1_node_type_volume_type;
+pub use self::scaleway_rdb_v1_node_type_volume_type::ScalewayRdbV1NodeTypeVolumeType;
+pub mod scaleway_rdb_v1_prepare_instance_logs_response;
+pub use self::scaleway_rdb_v1_prepare_instance_logs_response::ScalewayRdbV1PrepareInstanceLogsResponse;
+pub mod scaleway_rdb_v1_privilege;
+pub use self::scaleway_rdb_v1_privilege::ScalewayRdbV1Privilege;
+pub mod scaleway_rdb_v1_set_instance_acl_rules_response;
+pub use self::scaleway_rdb_v1_set_instance_acl_rules_response::ScalewayRdbV1SetInstanceAclRulesResponse;
+pub mod scaleway_rdb_v1_set_instance_settings_response;
+pub use self::scaleway_rdb_v1_set_instance_settings_response::ScalewayRdbV1SetInstanceSettingsResponse;
+pub mod scaleway_rdb_v1_snapshot;
+pub use self::scaleway_rdb_v1_snapshot::ScalewayRdbV1Snapshot;
+pub mod scaleway_rdb_v1_user;
+pub use self::scaleway_rdb_v1_user::ScalewayRdbV1User;
+pub mod scaleway_rdb_v1_volume_type;
+pub use self::scaleway_rdb_v1_volume_type::ScalewayRdbV1VolumeType;
 pub mod scaleway_registry_v1_image;
 pub use self::scaleway_registry_v1_image::ScalewayRegistryV1Image;
 pub mod scaleway_registry_v1_list_images_response;
@@ -472,6 +400,10 @@ pub mod scaleway_std_file;
 pub use self::scaleway_std_file::ScalewayStdFile;
 pub mod scaleway_std_service_info;
 pub use self::scaleway_std_service_info::ScalewayStdServiceInfo;
+pub mod scaleway_std_time_series;
+pub use self::scaleway_std_time_series::ScalewayStdTimeSeries;
+pub mod scaleway_std_time_series_point;
+pub use self::scaleway_std_time_series_point::ScalewayStdTimeSeriesPoint;
 pub mod scaleway_vpc_v1_list_private_networks_response;
 pub use self::scaleway_vpc_v1_list_private_networks_response::ScalewayVpcV1ListPrivateNetworksResponse;
 pub mod scaleway_vpc_v1_private_network;
